@@ -27,11 +27,24 @@ def parse(hub, client: "botocore.client.BaseClient", service: str, operation: st
     except AttributeError:
         return_type = None
 
+    return_fields = {}
+    if return_type == "structure" or return_type == "Dict":
+        try:
+            return_fields = next(
+                iter(doc._gen_kwargs["operation_model"].output_shape.members.items())
+            )[1].members
+        except AttributeError:
+            return_fields = {}
+
     ret = {
         "doc": "\n".join(hub.tool.format.wrap.wrap(docstring, width=112)),
         "params": parameters,
         "return_type": return_type,
-        "hardcoded": {"service": service, "operation": operation},
+        "hardcoded": {
+            "service": service,
+            "operation": operation,
+            "return_fields": return_fields,
+        },
     }
 
     return ret
