@@ -127,7 +127,7 @@ def parse(hub, session: "boto3.session.Session", service: str):
             "imports": [
                 "import copy",
                 "from typing import *",
-                "import dict_tools.differ as differ",
+                "__contracts__ = ['resource']",
             ],
             "functions": {},
             "doc": str(client.__doc__),
@@ -147,7 +147,6 @@ def parse(hub, session: "boto3.session.Session", service: str):
             "resource_id": "TODOs",
             "service_name": clean_service,
             "resource": resource,
-            "has_dry_run": False,
             "has_client_token": False,
             "is_idempotent": False,
             "tag_method": "TODO, unify the way resources are tagged",
@@ -162,7 +161,6 @@ def parse(hub, session: "boto3.session.Session", service: str):
             func_definition["hardcoded"].update(shared_function_data)
             func_definition["hardcoded"].update(
                 {
-                    "has_dry_run": bool(func_definition["params"].pop("DryRun", False)),
                     "has_client_token": func_definition["params"].pop(
                         "ClientToken", None
                     ),
@@ -182,7 +180,7 @@ def parse(hub, session: "boto3.session.Session", service: str):
                 if func_definition["hardcoded"]["is_idempotent"]:
                     name["doc"] = "The name of the state"
 
-            # Create a new param list the puts "name" first in the orderered dict
+            # Create a new param list the puts "name" first in the ordered dict
             func_definition["params"] = dict(
                 Name=name,
                 **func_definition["params"],
